FunctionLiteral class
Function literal: fn(x, y) { ... }
- Inheritance
-
- Object
- Node
- Expression
- FunctionLiteral
Constructors
-
FunctionLiteral(Token token, List<
Identifier> parameters, BlockStatement body)
Properties
- body → BlockStatement
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
parameters
→ List<
Identifier> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → Token
-
The token that opens this node — carries its line and column.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tokenLiteral(
) → String -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited